@@ -9,6 +9,8 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_events._jsii
+import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
@@ -19,9 +21,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-aurora-globaldatabase",
-    "0.1.23",
+    "1.0.20",
     __name__[0:-6],
-    "cdk-aurora-globaldatabase@0.1.23.jsii.tgz",
+    "cdk-aurora-globaldatabase@1.0.20.jsii.tgz",
 )
 
 __all__ = [
